@@ -1,8 +1,6 @@
 //
 // Path.cpp
 //
-// $Id: //poco/1.4/Foundation/src/Path.cpp#5 $
-//
 // Library: Foundation
 // Package: Filesystem
 // Module:  Path
@@ -25,9 +23,7 @@
 #include <algorithm>
 
 
-#if defined(POCO_OS_FAMILY_VMS)
-#include "Path_VMS.cpp"
-#elif defined(POCO_OS_FAMILY_UNIX)
+#if defined(POCO_OS_FAMILY_UNIX)
 #include "Path_UNIX.cpp"
 #elif defined(POCO_OS_FAMILY_WINDOWS) && defined(POCO_WIN32_UTF8)
 #if defined(_WIN32_WCE)
@@ -79,51 +75,51 @@ Path::Path(const char* path, Style style)
 }
 
 
-Path::Path(const Path& path): 
-	_node(path._node), 
+Path::Path(const Path& path):
+	_node(path._node),
 	_device(path._device),
 	_name(path._name),
 	_version(path._version),
 	_dirs(path._dirs),
 	_absolute(path._absolute)
-{	
+{
 }
 
 
 Path::Path(const Path& parent, const std::string& fileName):
-	_node(parent._node), 
+	_node(parent._node),
 	_device(parent._device),
 	_name(parent._name),
 	_version(parent._version),
 	_dirs(parent._dirs),
 	_absolute(parent._absolute)
-{	
+{
 	makeDirectory();
 	_name = fileName;
 }
 
 
 Path::Path(const Path& parent, const char* fileName):
-	_node(parent._node), 
+	_node(parent._node),
 	_device(parent._device),
 	_name(parent._name),
 	_version(parent._version),
 	_dirs(parent._dirs),
 	_absolute(parent._absolute)
-{	
+{
 	makeDirectory();
 	_name = fileName;
 }
 
 
 Path::Path(const Path& parent, const Path& relative):
-	_node(parent._node), 
+	_node(parent._node),
 	_device(parent._device),
 	_name(parent._name),
 	_version(parent._version),
 	_dirs(parent._dirs),
 	_absolute(parent._absolute)
-{	
+{
 	resolve(relative);
 }
 
@@ -132,13 +128,13 @@ Path::~Path()
 {
 }
 
-	
+
 Path& Path::operator = (const Path& path)
 {
 	return assign(path);
 }
 
-	
+
 Path& Path::operator = (const std::string& path)
 {
 	return assign(path);
@@ -180,9 +176,7 @@ Path& Path::assign(const Path& path)
 
 Path& Path::assign(const std::string& path)
 {
-#if defined(POCO_OS_FAMILY_VMS)
-	parseVMS(path);
-#elif defined(POCO_OS_FAMILY_WINDOWS)
+#if defined(POCO_OS_FAMILY_WINDOWS)
 	parseWindows(path);
 #else
 	parseUnix(path);
@@ -190,7 +184,7 @@ Path& Path::assign(const std::string& path)
 	return *this;
 }
 
-	
+
 Path& Path::assign(const std::string& path, Style style)
 {
 	switch (style)
@@ -225,16 +219,14 @@ Path& Path::assign(const char* path)
 
 std::string Path::toString() const
 {
-#if defined(POCO_OS_FAMILY_UNIX)
-	return buildUnix();
-#elif defined(POCO_OS_FAMILY_WINDOWS)
+#if defined(POCO_OS_FAMILY_WINDOWS)
 	return buildWindows();
 #else
-	return buildVMS();
+	return buildUnix();
 #endif
 }
 
-	
+
 std::string Path::toString(Style style) const
 {
 	switch (style)
@@ -303,11 +295,7 @@ Path& Path::parseDirectory(const std::string& path, Style style)
 
 Path& Path::makeDirectory()
 {
-#if defined(POCO_OS_FAMILY_VMS)
-	pushDirectory(getBaseName());
-#else
 	pushDirectory(_name);
-#endif
 	_name.clear();
 	_version.clear();
 	return *this;
@@ -320,9 +308,6 @@ Path& Path::makeFile()
 	{
 		_name = _dirs.back();
 		_dirs.pop_back();
-#if defined(POCO_OS_FAMILY_VMS)
-		setExtension("DIR");
-#endif
 	}
 	return *this;
 }
@@ -441,7 +426,7 @@ Path& Path::setNode(const std::string& node)
 	return *this;
 }
 
-	
+
 Path& Path::setDevice(const std::string& device)
 {
 	_device   = device;
@@ -449,43 +434,33 @@ Path& Path::setDevice(const std::string& device)
 	return *this;
 }
 
-	
+
 const std::string& Path::directory(int n) const
 {
 	poco_assert (0 <= n && n <= _dirs.size());
-	
+
 	if (n < _dirs.size())
 		return _dirs[n];
 	else
-		return _name;	
+		return _name;
 }
 
 
 const std::string& Path::operator [] (int n) const
 {
 	poco_assert (0 <= n && n <= _dirs.size());
-	
+
 	if (n < _dirs.size())
 		return _dirs[n];
 	else
-		return _name;	
+		return _name;
 }
 
-	
+
 Path& Path::pushDirectory(const std::string& dir)
 {
 	if (!dir.empty() && dir != ".")
 	{
-#if defined(POCO_OS_FAMILY_VMS)
-		if (dir == ".." || dir == "-")
-		{
-			if (!_dirs.empty() && _dirs.back() != ".." && _dirs.back() != "-")
-				_dirs.pop_back();
-			else if (!_absolute)
-				_dirs.push_back(dir);
-		}
-		else _dirs.push_back(dir);
-#else
 		if (dir == "..")
 		{
 			if (!_dirs.empty() && _dirs.back() != "..")
@@ -494,16 +469,15 @@ Path& Path::pushDirectory(const std::string& dir)
 				_dirs.push_back(dir);
 		}
 		else _dirs.push_back(dir);
-#endif
 	}
 	return *this;
 }
 
-	
+
 Path& Path::popDirectory()
 {
 	poco_assert (!_dirs.empty());
-	
+
 	_dirs.pop_back();
 	return *this;
 }
@@ -512,13 +486,13 @@ Path& Path::popDirectory()
 Path& Path::popFrontDirectory()
 {
 	poco_assert (!_dirs.empty());
-	
+
 	StringVec::iterator it = _dirs.begin();
 	_dirs.erase(it);
 	return *this;
 }
 
-	
+
 Path& Path::setFileName(const std::string& name)
 {
 	_name = name;
@@ -560,7 +534,7 @@ Path& Path::setExtension(const std::string& extension)
 	return *this;
 }
 
-			
+
 std::string Path::getExtension() const
 {
 	std::string::size_type pos = _name.rfind('.');
@@ -588,13 +562,13 @@ std::string Path::current()
 	return PathImpl::currentImpl();
 }
 
-	
+
 std::string Path::home()
 {
 	return PathImpl::homeImpl();
 }
 
-	
+
 std::string Path::temp()
 {
 	return PathImpl::tempImpl();
@@ -606,7 +580,7 @@ std::string Path::null()
 	return PathImpl::nullImpl();
 }
 
-	
+
 std::string Path::expand(const std::string& path)
 {
 	return PathImpl::expandImpl(path);
@@ -663,7 +637,7 @@ void Path::parseUnix(const std::string& path)
 
 	if (it != end)
 	{
-		if (*it == '/') 
+		if (*it == '/')
 		{
 			_absolute = true; ++it;
 		}
@@ -793,7 +767,7 @@ void Path::parseVMS(const std::string& path)
 						}
 					}
 				}
-			}			
+			}
 			if (name.empty())
 			{
 				if (it != end && *it == '[')
@@ -819,7 +793,7 @@ void Path::parseVMS(const std::string& path)
 								{
 									if (_dirs.empty() || _dirs.back() == "..")
 										_dirs.push_back("..");
-									else 
+									else
 										_dirs.pop_back();
 								}
 								else _dirs.push_back(name);
@@ -890,7 +864,7 @@ void Path::parseGuess(const std::string& path)
 			case '\\': hasBackslash = true; break;
 			case '/':  hasSlash = true; break;
 			case '[':  hasOpenBracket = true;
-			case ']':  hasClosBracket = hasOpenBracket; 
+			case ']':  hasClosBracket = hasOpenBracket;
 			case ';':  semiIt = it; break;
 			}
 		}
